@@ -25,9 +25,6 @@ import logging
 import mimetypes
 import os
 import re
-from typing import List, Optional
-
-from requests import Response
 
 from moss.ems.utilities import PaginationQuery
 
@@ -541,7 +538,6 @@ class EmsLayer(object):
         return True
 
     def delete_attachment(self, feature_id, attachment_ids):
-        #  type: (int, List[int]) -> bool
         """
         Enables the deletion of several existing files or ZIP archives of a feature.
 
@@ -549,7 +545,7 @@ class EmsLayer(object):
             feature_id (int): The ID of the feature
             attachments_id (list): The list of attachments id to delete
 
-        Return:
+        Returns:
             result (bool): If the operation war succesfull
         """
 
@@ -603,8 +599,9 @@ class EmsLayer(object):
             logger.info("The attachments were deleted successfully.")
         return True
 
-    def download_attachment(self, feature_id, attachment_id, output_path=None):
-        # type: (int, int, Optional[str]) -> Optional[bool]
+    def download_attachment(
+        self, feature_id, attachment_id, output_path=None, attachment_name=None
+    ):
         """
         Download the specified attachment
 
@@ -612,6 +609,9 @@ class EmsLayer(object):
             feature_id (int): The ID of the feature owning the attachment
             attachment_id (int): The attachments ID
             output_path (str): Output directory where the attachment will be saved
+            attachment_name (str): A name used to save the attachment. If not provided
+                we will use the name stored WEGA-EMS.
+
         Returns:
             bool: The result of the download attachment
         """
@@ -634,28 +634,37 @@ class EmsLayer(object):
             ]
         )
 
-        response = self._session.get(url)  # type: Response
-        content_type = response.headers.get("Content-Type")  # type: Optional[str]
+        response = self._session.get(url)
+        content_type = response.headers.get("Content-Type")
         if content_type is not None:
             if "application/json" not in content_type:
                 logger.info("Headers {0}".format(response.headers))
 
                 content_disposition = response.headers.get("Content-Disposition")
-                if content_disposition:
-                    filename = re.findall("filename=(.+)", content_disposition)[0]
-                else:
-                    filename = "no_name"
-                logger.info("Saving attachment to {0}".format(filename))
+                if attachment_name is None:
+                    logger.debug("No filename provided, using name from WEGA-EMS.")
+
+                    if content_disposition:
+                        attachment_name = re.findall(
+                            "filename=(.+)", content_disposition
+                        )[0]
+                    else:
+                        logger.warning(
+                            "Is not possible to find filename from WEGA-EMS."
+                            "Using standard name: no_name"
+                        )
+                        attachment_name = "no_name"
+                    logger.info("Saving attachment to {0}".format(attachment_name))
 
                 if output_path:
                     if not os.path.exists(output_path):
                         logger.error("The path {0} does not exist".format(output_path))
                         return False
 
-                    attachment_path = os.path.join(output_path, filename)
+                    attachment_path = os.path.join(output_path, attachment_name)
 
                 else:
-                    attachment_path = filename
+                    attachment_path = attachment_name
 
                 logger.debug("Saving attachment to {0}".format(attachment_path))
                 with open(attachment_path, "wb") as output_file:
@@ -664,6 +673,9 @@ class EmsLayer(object):
             else:
                 logger.error("The attachment url {0} does not exist".format(url))
                 return False
+        else:
+            logger.error("Error communicating with WEGA-EMS. Response %s", response)
+            return False
 
     def __repr__(self):
         return self.name
