@@ -55,7 +55,8 @@ class Service(object):
 
     To access a WEGA-EMS Service without authentication:
 
-    Example:
+    Examples:
+
         >>> my_service = Service("http://localhost:8080/wega-ems/")
         >>> my_service.projects
         ["project1", "project2"]
@@ -63,7 +64,8 @@ class Service(object):
     If the service uses authentication, username and password can be provided
     as additional parameters:
 
-    Example:
+    Examples:
+
         >>> my_service = Service("http://localhost:8080/wega-ems/",
                 username="Test",
                 password="Test")
@@ -72,7 +74,8 @@ class Service(object):
 
     If working wih token, you can easily ignore the username and password:
 
-    Example:
+    Examples:
+
         >>> my_service = Service("http://localhost:8080/wega-ems/",
                                 token="aabbcc")
         >>> my_service.projects
@@ -253,7 +256,7 @@ class Service(object):
         """
         The list of all the projects in the current Service.
 
-        Example:
+        Examples:
 
             >>> my_service = Service("http://localhost:8080/wega-ems/")
             >>> my_service.projects
@@ -282,7 +285,8 @@ class Service(object):
             description (str, optional): The project description.
             If not provided it will be an empty string.
 
-        Example:
+        Examples:
+
             >>> my_service = Service("http://localhost:8080/wega-ems/")
             >>> my_service.add_project("PROJECT", "Beschreibung")
 
@@ -390,7 +394,8 @@ class Service(object):
         """
         Returns a project class by the project name.
 
-        Example:
+        Examples:
+
             >>> my_service.project("prj1")
 
         Args:
@@ -417,7 +422,8 @@ class Service(object):
         """
         Exports the provided project
 
-        Example:
+        Examples:
+
             >>> my_service.export_project("prj1")
 
         Args:
@@ -449,7 +455,8 @@ class Service(object):
         """
         Import a project using the provided dict
 
-        Example:
+        Examples:
+
             >>> my_service.import_project("prj1")
 
         Args:
