@@ -156,6 +156,7 @@ class EmsCliDump:
         variants: Optional[str] = None,
         extension: str = "gpkg",
         output_filename: str = "export_ems",
+        export_layers: List[str] = None,
     ):
         logger.info("Starting dump..")
         logger.debug("Checking if output %s exists", output_path)
@@ -190,7 +191,14 @@ class EmsCliDump:
                     if isinstance(objectclass, str):
                         objectclass = self.project.objectclass(objectclass)
 
-                    layers: Optional[List[EmsLayer]] = objectclass.layers
+                    if export_layers is None:
+                        layers: Optional[List[EmsLayer]] = objectclass.layers
+                    else:
+                        layers = [
+                            layer
+                            for layer in objectclass.layers
+                            if str(layer) in export_layers
+                        ]
                     if layers is not None:
                         for layer in layers:
                             output_file_path = self._generate_output_file_name(
@@ -234,7 +242,14 @@ class EmsCliDump:
                 if isinstance(objectclass, str):
                     objectclass = self.project.objectclass(objectclass)
 
-                layers: Optional[List[EmsLayer]] = objectclass.layers
+                if export_layers is None:
+                    layers: Optional[List[EmsLayer]] = objectclass.layers
+                else:
+                    layers = [
+                        layer
+                        for layer in objectclass.layers
+                        if str(layer) in export_layers
+                    ]
                 if layers is not None:
                     for layer in layers:
                         output_file_path = self._generate_output_file_name(
